﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Twp.FC;
using Twp.Utilities;

namespace AOcrayon
{
	public partial class GuiBox : UserControl
	{
		public GuiBox()
		{
			InitializeComponent();
		}

		private bool loaded = false;

		private void OnLoad( object sender, EventArgs e )
		{
            if( this.DesignMode )
                return;

            if( Program.GameMode.SupportsGuiChange )
            {
                this.Visible = true;

                this.UpdateGuis();
                this.SetGui( Program.GameMode.CurrentGui );
                this.loaded = true;
            }
            else
                this.Visible = false;
		}

		internal void OnGuiChanged( object sender, EventArgs e )
		{
            string guiName = this.comboBox.SelectedItem.ToString();
            if( Program.GameMode.Colors.Loaded )
            {
                if( guiName == "Default" && this.comboBox.Items.Count > 1 && this.loaded )
                    Log.Information( Properties.Resources.DefaultGuiSelected );
                this.ReloadGui( guiName );
			}
		}

		internal void OnReloadClicked( object sender, EventArgs e )
		{
			this.ReloadGui();
		}

		private void UpdateGuis()
		{
			this.comboBox.Items.Clear();
            string[] guiDirs = Program.GameMode.AvailableGuis;
            if( guiDirs != null )
            {
                this.comboBox.Items.AddRange( guiDirs );
                if( guiDirs.Length > 1 )
                {
                    this.Enabled = true;
                }
                else
                {
                    if( this.MaybeCreateGui( guiDirs[0] ) == true )
                        return;
                    this.Enabled = false;
                }
            }
            else
            {
                this.Enabled = false;
            }
        }

		public void SetGui( string gui )
		{
			Log.Debug( "[GuiBox.SetGui] GUI: {0}", gui );
			if( String.IsNullOrEmpty( gui ) )
				gui = "Default";

			if( gui == "Default" && this.comboBox.Items.Count > 1 )
				Log.Information( Properties.Resources.DefaultGuiSelected );

			if( this.comboBox.Items.Contains( gui ) )
			{
				Log.Debug( "[GuiBox.SetGui] Gui found." );
				this.comboBox.SelectedItem = gui;
			}
			else
			{
				Log.Debug( "[GuiBox.SetGui] Gui not found. Selecting Default." );
				this.comboBox.SelectedItem = "Default";
			}
		}

		private bool MaybeCreateGui( string gui )
		{
			if( gui != "Default" )
			{
				Log.Error( Properties.Resources.NoDefaultGui );
				return false;
			}
			else
			{
				DialogResult dr = MessageBox.Show( Properties.Resources.OnlyDefaultGui,
												   Properties.Resources.OnlyDefaultGuiCaption,
												   MessageBoxButtons.YesNo,
												   MessageBoxIcon.Question );
				if( dr == DialogResult.Yes )
				{
					//this.copyLabel.Text = String.Empty;
					//this.copyLabel.Visible = true;
					//Path.IOEvent += new Path.IOEventHandler( this.OnIOEvent );

                    //string source = Gui.GetPath( Program.Settings.AOPath, gui );
                    //string target = Gui.GetPath( Program.Settings.AOPath, "Modified" );
                    //Path.Copy( source, target );

					//Path.IOEvent -= new Path.IOEventHandler( this.OnIOEvent );
					//this.copyLabel.Visible = false;

					this.UpdateGuis();
					this.SetGui( "Modified" );
                    //Program.Colors.Load();

					return true;
				}
			}
			return false;
		}

		internal void ReloadGui( string guiName = null )
		{
			if( this.loaded )
			{
				DialogResult dr = MessageBox.Show( Properties.Resources.ReloadText,
												   Properties.Resources.ReloadCaption,
												   MessageBoxButtons.YesNo,
												   MessageBoxIcon.Warning );
				if( dr == DialogResult.Yes )
				{
                    if( !String.IsNullOrEmpty( guiName ) )
                        Program.GameMode.CurrentGui = guiName;
				}
			}
			else
                Program.GameMode.CurrentGui = guiName;
		}
	}
}
